@@ -15,15 +15,13 @@ class Simulator;
  */
 class Entity {
 public:
-  CLONEABLE(Entity)
-  
   Simulator* sim;
   std::string name;
   
-  Entity(Simulator* sim, std::string name, int mon): 
-    sim(sim), name(name), mon(std::abs(mon)) {}
+  Entity(Simulator* sim, std::string name, int mon)
+    : sim(sim), name(name), mon(std::abs(mon)) {}
   virtual ~Entity() {}
-  virtual void reset() {};
+  virtual void reset() = 0;
   int is_monitored() { return mon; }
   
 private:
