@@ -33,6 +33,7 @@ class Simulator {
   typedef MSET<Event> PQueue;
   typedef UMAP<Process*, PQueue::iterator> EvMap;
   typedef UMAP<std::string, Entity*> EntMap;
+  typedef USET<Arrival*> ArrSet;
   typedef UMAP<std::string, Batched*> NamBMap;
   typedef UMAP<Activity*, Batched*> UnnBMap;
   
@@ -45,7 +46,8 @@ public:
    * @param name    simulator name
    * @param verbose verbose flag
    */
-  Simulator(std::string name, bool verbose): name(name), verbose(verbose), now_(0), b_count(0) {}
+  Simulator(std::string name, bool verbose)
+    : name(name), verbose(verbose), now_(0), b_count(0) {}
   
   ~Simulator() {
     foreach_ (PQueue::value_type& itr, event_queue)
@@ -79,6 +81,7 @@ public:
       if (itr.second) delete itr.second;
     foreach_ (UnnBMap::value_type& itr, unnamedb_map)
       if (itr.second) delete itr.second;
+    arrival_set.clear();
     namedb_map.clear();
     unnamedb_map.clear();
     b_count = 0;
@@ -111,26 +114,33 @@ public:
   std::pair<VEC<double>, VEC<std::string> > peek(int steps) {
     VEC<double> time;
     VEC<std::string> process;
-    if (steps) { foreach_ (PQueue::value_type& itr, event_queue) {
-      time.push_back(itr.time);
-      process.push_back(itr.process->name);
-      if (!--steps) break;
-    }}
+    if (steps) {
+      foreach_ (PQueue::value_type& itr, event_queue) {
+        time.push_back(itr.time);
+        process.push_back(itr.process->name);
+        if (!--steps) break;
+      }
+    }
     return std::make_pair(time, process);
   }
   
   /**
    * Process the next event. Only one step, a giant leap for mankind.
    */
-  bool step() {
-    if (event_queue.empty()) return 0;
+  bool step(double until = -1) {
+    if (event_queue.empty())
+      return false;
     PQueue::iterator ev = event_queue.begin();
-    event_map.erase(ev->process);
+    if (until >= 0 && until <= ev->time) {
+      if (until > now_)
+        now_ = until;
+      return false;
+    }
     now_ = ev->time;
+    event_map.erase(ev->process);
     ev->process->run();
     event_queue.erase(ev);
-    return 1;
-    // ... and that's it! :D
+    return true;
   }
   
   /**
@@ -139,7 +149,7 @@ public:
    */
   void run(double until) {
     long int nsteps = 0;
-    while ((now_ < until || until < 0) && step())
+    while (step(until))
       if (++nsteps % 100000 == 0)
         Rcpp::checkUserInterrupt();
   }
@@ -155,16 +165,17 @@ public:
    * @param   restart         whether activity must be restarted after preemption
    */
   bool add_generator(std::string name_prefix, Activity* first_activity, Rcpp::Function dist, 
-                     int mon, int priority, int preemptible, bool restart) {
-    if (process_map.find(name_prefix) == process_map.end()) {
-      Generator* gen = new Generator(this, name_prefix, mon, first_activity, dist,
-                                     Order(priority, preemptible, restart));
-      process_map[name_prefix] = gen;
-      gen->run();
-      return TRUE;
+                     int mon, int priority, int preemptible, bool restart)
+  {
+    if (process_map.find(name_prefix) != process_map.end()) {
+      Rcpp::warning("process " + name_prefix + " already defined");
+      return false;
     }
-    Rcpp::warning("process " + name_prefix + " already defined");
-    return FALSE;
+    Generator* gen = new Generator(this, name_prefix, mon, first_activity, dist,
+                                   Order(priority, preemptible, restart));
+    process_map[name_prefix] = gen;
+    gen->run();
+    return true;
   }
   
   /**
@@ -178,21 +189,23 @@ public:
    * @param   keep_queue    whether the queue size is a hard limit
    */
   bool add_resource(std::string name, int capacity, int queue_size, bool mon,
-                    bool preemptive, std::string preempt_order, bool keep_queue) {
-    if (resource_map.find(name) == resource_map.end()) {
-      Resource* res;
-      if (!preemptive)
-        res = new PriorityRes<FIFO>(this, name, mon, capacity, queue_size);
-      else {
-        if (preempt_order.compare("fifo") == 0)
-          res = new PreemptiveRes<FIFO>(this, name, mon, capacity, queue_size, keep_queue);
-        else res = new PreemptiveRes<LIFO>(this, name, mon, capacity, queue_size, keep_queue);
-      }
-      resource_map[name] = res;
-      return TRUE;
+                    bool preemptive, std::string preempt_order, bool keep_queue)
+  {
+    if (resource_map.find(name) != resource_map.end()) {
+      Rcpp::warning("resource " + name + " already defined");
+      return false;
     }
-    Rcpp::warning("resource " + name + " already defined");
-    return FALSE;
+    Resource* res;
+    if (!preemptive) {
+      res = new PriorityRes<FIFO>(this, name, mon, capacity, queue_size);
+    } else {
+      if (preempt_order.compare("fifo") == 0)
+        res = new PreemptiveRes<FIFO>(this, name, mon, capacity, queue_size, keep_queue);
+      else 
+        res = new PreemptiveRes<LIFO>(this, name, mon, capacity, queue_size, keep_queue);
+    }
+    resource_map[name] = res;
+    return true;
   }
   
   /**
@@ -204,25 +217,26 @@ public:
    * @param   value     vector of values
    */
   bool add_resource_manager(std::string name, std::string param, 
-                            VEC<double> duration, VEC<int> value, int period) {
-    if (process_map.find(name) == process_map.end()) {
-      EntMap::iterator search = resource_map.find(name);
-      if (search == resource_map.end())
-        Rcpp::stop("resource '" + name + "' not found (typo?)");
-      Resource* res = (Resource*)search->second;
-      
-      Manager* manager;
-      if (param.compare("capacity") == 0)
-        manager = new Manager(this, name, param, duration, value, period,
-                              boost::bind(&Resource::set_capacity, res, _1));
-      else manager = new Manager(this, name, param, duration, value, period,
-                                 boost::bind(&Resource::set_queue_size, res, _1));
-      process_map[name + "_" + param] = manager;
-      manager->run();
-      return TRUE;
+                            VEC<double> duration, VEC<int> value, int period)
+  {
+    if (process_map.find(name) != process_map.end()) {
+      Rcpp::warning("process " + name + " already defined");
+      return false;
     }
-    Rcpp::warning("process " + name + " already defined");
-    return FALSE;
+    EntMap::iterator search = resource_map.find(name);
+    if (search == resource_map.end())
+      Rcpp::stop("resource '" + name + "' not found (typo?)");
+    Resource* res = (Resource*)search->second;
+    Manager* manager;
+    if (param.compare("capacity") == 0)
+      manager = new Manager(this, name, param, duration, value, period,
+                            boost::bind(&Resource::set_capacity, res, _1));
+    else 
+      manager = new Manager(this, name, param, duration, value, period,
+                            boost::bind(&Resource::set_queue_size, res, _1));
+    process_map[name + "_" + param] = manager;
+    manager->run();
+    return true;
   }
   
   /**
@@ -259,6 +273,9 @@ public:
   
   unsigned int get_batch_count() { return b_count++; }
   
+  void register_arrival(Arrival* arrival) { arrival_set.emplace(arrival); }
+  void unregister_arrival(Arrival* arrival) { arrival_set.erase(arrival); }
+  
   /**
    * Record monitoring data.
    */
@@ -295,23 +312,61 @@ public:
   /**
    * Get monitoring data.
    */
-  Rcpp::List get_arr_traj_stats() {
-    return Rcpp::List::create(
-        Rcpp::Named("name")           = arr_traj_stats.get<std::string>("name"),
-        Rcpp::Named("start_time")     = arr_traj_stats.get<double>("start_time"),
-        Rcpp::Named("end_time")       = arr_traj_stats.get<double>("end_time"),
-        Rcpp::Named("activity_time")  = arr_traj_stats.get<double>("activity_time"),
-        Rcpp::Named("finished")       = arr_traj_stats.get<bool>("finished")
-    );
-  }
-  Rcpp::List get_arr_res_stats() {
-    return Rcpp::List::create(
-      Rcpp::Named("name")             = arr_res_stats.get<std::string>("name"),
-      Rcpp::Named("start_time")       = arr_res_stats.get<double>("start_time"),
-      Rcpp::Named("end_time")         = arr_res_stats.get<double>("end_time"),
-      Rcpp::Named("activity_time")    = arr_res_stats.get<double>("activity_time"),
-      Rcpp::Named("resource")         = arr_res_stats.get<std::string>("resource")
-    );
+  Rcpp::List get_arr_stats(bool per_resource, bool ongoing) {
+    if (!per_resource) {
+      VEC<std::string> name             = arr_traj_stats.get<std::string>("name");
+      VEC<double> start_time            = arr_traj_stats.get<double>("start_time");
+      VEC<double> end_time              = arr_traj_stats.get<double>("end_time");
+      VEC<double> activity_time         = arr_traj_stats.get<double>("activity_time");
+      Rcpp::LogicalVector finished      = Rcpp::wrap(arr_traj_stats.get<bool>("finished"));
+      if (ongoing) {
+        foreach_ (Arrival* arrival, arrival_set) {
+          if (!arrival->is_monitored())
+            continue;
+          name.push_back(arrival->name);
+          start_time.push_back(arrival->get_start());
+          end_time.push_back(R_NaReal);
+          activity_time.push_back(R_NaReal);
+          finished.push_back(R_NaInt);
+        }
+      }
+      return Rcpp::List::create(
+          Rcpp::Named("name")           = name,
+          Rcpp::Named("start_time")     = start_time,
+          Rcpp::Named("end_time")       = end_time,
+          Rcpp::Named("activity_time")  = activity_time,
+          Rcpp::Named("finished")       = finished
+      );
+    } else {
+      VEC<std::string> name             = arr_res_stats.get<std::string>("name");
+      VEC<double> start_time            = arr_res_stats.get<double>("start_time");
+      VEC<double> end_time              = arr_res_stats.get<double>("end_time");
+      VEC<double> activity_time         = arr_res_stats.get<double>("activity_time");
+      VEC<std::string> resource         = arr_res_stats.get<std::string>("resource");
+      if (ongoing) {
+        foreach_ (Arrival* arrival, arrival_set) {
+          if (!arrival->is_monitored())
+            continue;
+          foreach_ (EntMap::value_type& itr, resource_map) {
+            double start = arrival->get_start(itr.second->name);
+            if (start < 0)
+              continue;
+            name.push_back(arrival->name);
+            start_time.push_back(start);
+            end_time.push_back(R_NaReal);
+            activity_time.push_back(R_NaReal);
+            resource.push_back(itr.second->name);
+          }
+        }
+      }
+      return Rcpp::List::create(
+        Rcpp::Named("name")             = name,
+        Rcpp::Named("start_time")       = start_time,
+        Rcpp::Named("end_time")         = end_time,
+        Rcpp::Named("activity_time")    = activity_time,
+        Rcpp::Named("resource")         = resource
+      );
+    }
   }
   Rcpp::List get_attr_stats() {
     return Rcpp::List::create(
@@ -354,6 +409,7 @@ private:
   EntMap resource_map;      /**< map of resources */
   EntMap process_map;       /**< map of processes */
   EvMap event_map;          /**< map of pending events */
+  ArrSet arrival_set;       /**< set of ongoing arrivals */
   NamBMap namedb_map;       /**< map of named batches */
   UnnBMap unnamedb_map;     /**< map of unnamed batches */
   unsigned int b_count;     /**< unnamed batch counter */
