@@ -2,26 +2,10 @@ context("convenience funcs")
 
 test_that("at returns the correct values", {
   gen_func <- at(c(0, 10, 15)) # values passed as vector
-  expect_equal(gen_func(), 0)
-  expect_equal(gen_func(), 10)
-  expect_equal(gen_func(), 5)
-  expect_equal(gen_func(), -1)
+  expect_equal(gen_func(), c(0, 10, 5, -1))
   
   gen_func <- at(0, 10, 15) # values passed as parameters
-  expect_equal(gen_func(), 0)
-  expect_equal(gen_func(), 10)
-  expect_equal(gen_func(), 5)
-  expect_equal(gen_func(), -1)
-})
-
-test_that("every returns the correct values", {
-  gen_func <- every(1, 2, 3)
-  expect_equal(gen_func(), 1)
-  expect_equal(gen_func(), 2)
-  expect_equal(gen_func(), 3)
-  expect_equal(gen_func(), 1)
-  expect_equal(gen_func(), 2)
-  expect_equal(gen_func(), 3)
+  expect_equal(gen_func(), c(0, 10, 5, -1))
 })
 
 test_that("from returns the correct values", {
@@ -39,6 +23,13 @@ test_that("to returns the correct values", {
   expect_equal(gen_func(), 1)
   expect_equal(gen_func(), 1)
   expect_equal(gen_func(), -1)
+  
+  gen_func <- to(3, function() c(1, 1))
+  expect_equal(gen_func(), c(1, 1))
+  expect_equal(gen_func(), -1)
+  
+  gen_func <- to(3, function() c(1, 1, 1))
+  expect_equal(gen_func(), c(1, 1, -1))
 })
 
 test_that("from_to returns the correct values", {
@@ -48,10 +39,26 @@ test_that("from_to returns the correct values", {
   expect_equal(gen_func(), 1)
   expect_equal(gen_func(), -1)
   
+  gen_func <- from_to(5, 8, function() c(1, 1))
+  expect_equal(gen_func(), 5)
+  expect_equal(gen_func(), c(1, 1))
+  expect_equal(gen_func(), -1)
+  
+  gen_func <- from_to(5, 8, function() c(1, 1, 1))
+  expect_equal(gen_func(), 5)
+  expect_equal(gen_func(), c(1, 1, -1))
+  
   gen_func2 <- from_to(5, 8, function() 1, arrive = FALSE)
   expect_equal(gen_func2(), 6)
   expect_equal(gen_func2(), 1)
   expect_equal(gen_func2(), -1)
+  
+  gen_func2 <- from_to(5, 8, function() c(1, 1), arrive = FALSE)
+  expect_equal(gen_func2(), c(6, 1))
+  expect_equal(gen_func2(), -1)
+  
+  gen_func2 <- from_to(5, 8, function() c(1, 1, 1), arrive = FALSE)
+  expect_equal(gen_func2(), c(6, 1, -1))
 })
 
 test_that("schedule returns the correct values", {
