@@ -1,5 +1,19 @@
 context("set_prioritization")
 
+test_that("the wrong number of parameters fails", {
+  expect_output(create_trajectory() %>% set_prioritization(c(0, 0, 0)) %>% print,
+                ".*SetPrior.*values: 0 0 0.*")
+  expect_error(create_trajectory() %>% set_prioritization(c(0, 0)) %>% print)
+  
+  t <- create_trajectory() %>%
+    set_prioritization(function() c(0, 0))
+  
+  env <- simmer(verbose=TRUE) %>%
+    add_generator("dummy", t, at(0))
+  
+  expect_error(env %>% run)
+})
+
 test_that("priority queues are adhered to (2)", {
   t0 <- create_trajectory() %>%
     seize("server", 1) %>%
