@@ -8,19 +8,30 @@ test_that("the wrapper behaves as expected", {
     set_attribute("attr", 1) %>%
     release("server", 1)
   
+  t1 <- create_trajectory() %>%
+    seize("server", 1) %>%
+    timeout(1) %>%
+    rollback(1, times=Inf)
+  
   env <- simmer() %>%
     add_resource("server", 1, 0) %>%
     add_generator("dummy", t0, at(1:10), mon=2) %>%
-    run() %>%
+    add_generator("rollback", t1, at(11)) %>%
+    run(11.5) %>%
     wrap()
   
   expect_output(print(env))
   
-  expect_equal(env%>%now(), 10)
-  expect_equal(env%>%peek(), numeric(0))
+  expect_equal(env%>%now(), 11.5)
+  expect_equal(env%>%peek(), 12)
   
-  arrivals <- env%>%get_mon_arrivals()
-  arrivals_res <- env%>%get_mon_arrivals(TRUE)
+  arrivals <- env%>%get_mon_arrivals(ongoing = TRUE)
+  arrivals_res <- env%>%get_mon_arrivals(TRUE, ongoing = TRUE)
+  expect_equal(nrow(arrivals), 11)
+  expect_equal(nrow(arrivals_res), 11)
+  
+  arrivals <- env%>%get_mon_arrivals(ongoing = FALSE)
+  arrivals_res <- env%>%get_mon_arrivals(TRUE, ongoing = FALSE)
   attributes <- env%>%get_mon_attributes()
   resources <- env%>%get_mon_resources("counts")
   resources <- env%>%get_mon_resources("limits")
@@ -29,7 +40,7 @@ test_that("the wrapper behaves as expected", {
   expect_equal(nrow(arrivals), 10)
   expect_equal(nrow(arrivals_res), 10)
   expect_equal(nrow(attributes), 10)
-  expect_equal(nrow(resources), 20)
+  expect_equal(nrow(resources), 21)
   expect_error(env%>%get_n_generated("asdf"))
   expect_equal(env%>%get_n_generated("dummy"), 10)
   expect_error(env%>%get_capacity("asdf"))
@@ -37,7 +48,7 @@ test_that("the wrapper behaves as expected", {
   expect_error(env%>%get_queue_size("asdf"))
   expect_equal(env%>%get_queue_size("server"), 0)
   expect_error(env%>%get_server_count("asdf"))
-  expect_equal(env%>%get_server_count("server"), 0)
+  expect_equal(env%>%get_server_count("server"), 1)
   expect_error(env%>%get_queue_count("asdf"))
   expect_equal(env%>%get_queue_count("server"), 0)
 })
